==> huaweicloudsdkvpc-3.1.134-py2.py3-none-any.whl: huaweicloudsdkvpc/v3/model/show_port_tags_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowPortTagsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'tags': 'list[ResourceTag]',
        'request_id': 'str'
    }

    attribute_map = {
        'tags': 'tags',
        'request_id': 'request_id'
    }

    def __init__(self, tags=None, request_id=None):
        """ShowPortTagsResponse

        The model defined in huaweicloud sdk

        :param tags: tag对象列表
        :type tags: list[:class:`huaweicloudsdkvpc.v3.ResourceTag`]
        :param request_id: 请求ID
        :type request_id: str
        """
        
        super(ShowPortTagsResponse, self).__init__()

        self._tags = None
        self._request_id = None
        self.discriminator = None

        if tags is not None:
            self.tags = tags
        if request_id is not None:
            self.request_id = request_id

    @property
    def tags(self):
        """Gets the tags of this ShowPortTagsResponse.

        tag对象列表

        :return: The tags of this ShowPortTagsResponse.
        :rtype: list[:class:`huaweicloudsdkvpc.v3.ResourceTag`]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this ShowPortTagsResponse.

        tag对象列表

        :param tags: The tags of this ShowPortTagsResponse.
        :type tags: list[:class:`huaweicloudsdkvpc.v3.ResourceTag`]
        """
        self._tags = tags

    @property
    def request_id(self):
        """Gets the request_id of this ShowPortTagsResponse.

        请求ID

        :return: The request_id of this ShowPortTagsResponse.
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this ShowPortTagsResponse.

        请求ID

        :param request_id: The request_id of this ShowPortTagsResponse.
        :type request_id: str
        """
        self._request_id = request_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowPortTagsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkvpc-3.1.150-py2.py3-none-any.whl: huaweicloudsdkvpc/v3/model/show_port_tags_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowPortTagsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'tags': 'list[ResourceTag]',
        'request_id': 'str'
    }

    attribute_map = {
        'tags': 'tags',
        'request_id': 'request_id'
    }

    def __init__(self, tags=None, request_id=None):
        r"""ShowPortTagsResponse

        The model defined in huaweicloud sdk

        :param tags: tag对象列表
        :type tags: list[:class:`huaweicloudsdkvpc.v3.ResourceTag`]
        :param request_id: 请求ID
        :type request_id: str
        """
        
        super(ShowPortTagsResponse, self).__init__()

        self._tags = None
        self._request_id = None
        self.discriminator = None

        if tags is not None:
            self.tags = tags
        if request_id is not None:
            self.request_id = request_id

    @property
    def tags(self):
        r"""Gets the tags of this ShowPortTagsResponse.

        tag对象列表

        :return: The tags of this ShowPortTagsResponse.
        :rtype: list[:class:`huaweicloudsdkvpc.v3.ResourceTag`]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        r"""Sets the tags of this ShowPortTagsResponse.

        tag对象列表

        :param tags: The tags of this ShowPortTagsResponse.
        :type tags: list[:class:`huaweicloudsdkvpc.v3.ResourceTag`]
        """
        self._tags = tags

    @property
    def request_id(self):
        r"""Gets the request_id of this ShowPortTagsResponse.

        请求ID

        :return: The request_id of this ShowPortTagsResponse.
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        r"""Sets the request_id of this ShowPortTagsResponse.

        请求ID

        :param request_id: The request_id of this ShowPortTagsResponse.
        :type request_id: str
        """
        self._request_id = request_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowPortTagsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
